@@ -1,7 +1,16 @@
 import os
 
 
-_DEFAULT_BUCKETS = [0.05, 0.1, 0.5, 0.9, 0.95]
+_DEFAULT_BUCKETS_BACKUP = [0.05, 0.1, 0.5, 0.9, 0.95]
+_DEFAULT_BUCKETS = [
+    0.05,
+    0.1,
+    0.5,
+    1.0,
+    1.5,
+    3.0,
+    5.0,
+]
 _DEFAULT_LABELS = ["method", "route", "http_status", "serviceName", "namespace"]
 
 NAMESPACE = os.getenv("SERVICE_NAME_PREFIX", default="UNDEFINED")
