@@ -353,12 +353,9 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
 
         def fastapi_after_request(response, request):
             # path_format = get_path_format(request.app.routes, request.url.path)
-            request_path = request.scope.get("raw_path")
-            request_path = (
-                request_path.decode("utf-8") if request_path else request.url.path
+            path_format = get_path_format(
+                request.app.routes, request.scope.get("path", request.url.path)
             )
-
-            path_format = get_path_format(request.app.routes, request_path)
             if not self.is_exclude(request.method, path_format, response.status_code):
                 request_latency = (
                     time.time() - request._prometheus_metrics_request_start_time
